emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] master 7334982: ; Spelling fixes


From: Paul Eggert
Subject: [Emacs-diffs] master 7334982: ; Spelling fixes
Date: Thu, 22 Dec 2016 18:14:15 +0000 (UTC)

branch: master
commit 73349822cbd6e50526eda9c75453584d73dfca83
Author: Paul Eggert <address@hidden>
Commit: Paul Eggert <address@hidden>

    ; Spelling fixes
---
 ChangeLog.2                      |    2 +-
 doc/lispref/streams.texi         |    2 +-
 doc/lispref/variables.texi       |    2 +-
 etc/NEWS                         |    2 +-
 lisp/bookmark.el                 |    2 +-
 lisp/cedet/semantic/db-global.el |    2 +-
 lisp/image-dired.el              |    8 ++++----
 lisp/vc/diff-mode.el             |    2 +-
 lisp/vc/ediff-init.el            |    2 +-
 lisp/vc/ediff-ptch.el            |    8 ++++----
 src/ChangeLog.13                 |    2 +-
 src/ChangeLog.3                  |    2 +-
 src/process.c                    |   11 +++++------
 src/systhread.c                  |    2 +-
 src/thread.c                     |   11 +++++------
 src/thread.h                     |    4 ++--
 test/lisp/net/tramp-tests.el     |    2 +-
 test/lisp/vc/vc-tests.el         |    2 +-
 test/src/thread-tests.el         |    2 +-
 19 files changed, 34 insertions(+), 36 deletions(-)

diff --git a/ChangeLog.2 b/ChangeLog.2
index 0b73dc2..de67bbf 100644
--- a/ChangeLog.2
+++ b/ChangeLog.2
@@ -26205,7 +26205,7 @@
 
 2015-08-07  Phillip Lord  <address@hidden>
 
-       Improve error signalling for seq-subseq
+       Improve error signaling for seq-subseq
        * lisp/emacs-lisp/seq.el (seq-subseq): The existing behavior is to error
        when indexes are too large, but to silently ignore numbers which
        are too negative for lists.  String and vector handling errors in
diff --git a/doc/lispref/streams.texi b/doc/lispref/streams.texi
index 41bc71e..757e0e8 100644
--- a/doc/lispref/streams.texi
+++ b/doc/lispref/streams.texi
@@ -639,7 +639,7 @@ spacing between calls.
 This function outputs a newline to @var{stream}.  The name stands for
 ``terminate print''.  If @var{ensure} is address@hidden no newline is printed
 if @var{stream} is already at the beginning of a line.  Note in this
-case @var{stream} can not be a function and an error is signalled if
+case @var{stream} can not be a function and an error is signaled if
 it is.  This function returns @code{t} if a newline is printed.
 @end defun
 
diff --git a/doc/lispref/variables.texi b/doc/lispref/variables.texi
index 40738e6..d9096da 100644
--- a/doc/lispref/variables.texi
+++ b/doc/lispref/variables.texi
@@ -809,7 +809,7 @@ functions.
 
 @subsection Limitations
 
-There are a couple of ways in which a variable could be modifed (or at
+There are a couple of ways in which a variable could be modified (or at
 least appear to be modified) without triggering a watchpoint.
 
 Since watchpoints are attached to symbols, modification to the
diff --git a/etc/NEWS b/etc/NEWS
index 9fbbf5c..8306a66 100644
--- a/etc/NEWS
+++ b/etc/NEWS
@@ -512,7 +512,7 @@ instead of shell command strings.  This change affects
 'image-dired-cmd-pngnq-options', 'image-dired-cmd-pngcrush-options',
 'image-dired-cmd-create-standard-thumbnail-options'
 
-*** Recognizes more tools by default, including pngnq-s9, optipng, and gm
+*** Recognizes more tools by default, including pngnq-s9, OptiPNG, and gm
 
 *** 'find-file' and related commands now work on thumbnails and
 displayed images, providing a default argument of the original file name
diff --git a/lisp/bookmark.el b/lisp/bookmark.el
index f3c8b2a..7d45832 100644
--- a/lisp/bookmark.el
+++ b/lisp/bookmark.el
@@ -2123,7 +2123,7 @@ To carry out the deletions that you've marked, use 
\\<bookmark-bmenu-mode-map>\\
                            (current-buffer))))
           (read-string "Pattern: ")
           (when timer (cancel-timer timer) (setq timer nil)))
-      (when timer ;; Signalled an error or a `quit'.
+      (when timer ;; Signaled an error or a `quit'.
         (cancel-timer timer)
         (bookmark-bmenu-list)
         (bookmark-bmenu-goto-bookmark bmk)))))
diff --git a/lisp/cedet/semantic/db-global.el b/lisp/cedet/semantic/db-global.el
index 03a21b0..4793c53 100644
--- a/lisp/cedet/semantic/db-global.el
+++ b/lisp/cedet/semantic/db-global.el
@@ -47,7 +47,7 @@ in a GNU Global supported hierarchy.
 
 Two sanity checks are performed to assure (a) that GNU global program exists
 and (b) that the GNU global program version is compatibility with the database
-version.  If optional NOERROR is nil, then an error may be signalled on version
+version.  If optional NOERROR is nil, then an error may be signaled on version
 mismatch.  If NOERROR is not nil, then no error will be signaled.  Instead
 return value will indicate success or failure with non-nil or nil respective
 values."
diff --git a/lisp/image-dired.el b/lisp/image-dired.el
index 560cadb..2af72fc 100644
--- a/lisp/image-dired.el
+++ b/lisp/image-dired.el
@@ -262,7 +262,7 @@ is replaced by the file name of the temporary file."
       (executable-find "pngnq-s9"))
   "The file name of the `pngnq' program.
 It quantizes colors of PNG images down to 256 colors or fewer
-using the Neuquant procedure."
+using the NeuQuant algorithm."
   :version "26.1"
   :type '(choice (const :tag "Not Set" nil) file)
   :group 'image-dired)
@@ -702,7 +702,7 @@ Increase at own risk.")
     process))
 
 (defun image-dired-pngcrush-thumb (spec)
-  "Optimize thumbnail decsribed by format SPEC with pngcrush(1)."
+  "Optimize thumbnail described by format SPEC with pngcrush(1)."
   ;; If pngnq wasn't run, then the THUMB-nq8.png file does not exist.
   ;; pngcrush needs an infile and outfile, so we just copy THUMB to
   ;; THUMB-nq8.png and use the latter as a temp file.
@@ -727,7 +727,7 @@ Increase at own risk.")
     process))
 
 (defun image-dired-optipng-thumb (spec)
-  "Optimize thumbnail decsribed by format SPEC with optipng(1)."
+  "Optimize thumbnail described by format SPEC with optipng(1)."
   (let ((process
          (apply #'start-process "image-dired-optipng" nil
                 image-dired-cmd-optipng-program
@@ -765,7 +765,7 @@ Increase at own risk.")
       (make-directory thumbnail-dir t)
       (set-file-modes thumbnail-dir #o700))
 
-    ;; Thumbnail file creation processes begin here and are marshalled
+    ;; Thumbnail file creation processes begin here and are marshaled
     ;; in a queue by `image-dired-create-thumb'.
     (setq process
           (apply #'start-process "image-dired-create-thumbnail" nil
diff --git a/lisp/vc/diff-mode.el b/lisp/vc/diff-mode.el
index 5b48c8d..d5ea002 100644
--- a/lisp/vc/diff-mode.el
+++ b/lisp/vc/diff-mode.el
@@ -1884,7 +1884,7 @@ With a prefix argument, REVERSE the hunk."
       ;; Advance to the next hunk with skip-hunk-start set to t
       ;; because we want the behavior of moving to the next logical
       ;; hunk, not the original behavior where were would sometimes
-      ;; stay on the curent hunk.  This is the behavior we get when
+      ;; stay on the current hunk.  This is the behavior we get when
       ;; navigating through hunks interactively, and we want it when
       ;; applying hunks too (see http://debbugs.gnu.org/17544).
       (when diff-advance-after-apply-hunk
diff --git a/lisp/vc/ediff-init.el b/lisp/vc/ediff-init.el
index b0d5d2f..c96a968 100644
--- a/lisp/vc/ediff-init.el
+++ b/lisp/vc/ediff-init.el
@@ -318,7 +318,7 @@ It needs to be killed when we quit the session.")
 (defsubst ediff-patch-metajob (&optional metajob)
   (memq (or metajob ediff-metajob-name)
        '(ediff-multifile-patch)))
-;; metajob involving only one group of files, such as multipatch or directory
+;; metajob involving only one group of files, such as multi-patch or directory
 ;; revision
 (defsubst ediff-one-filegroup-metajob (&optional metajob)
   (or (ediff-revision-metajob metajob)
diff --git a/lisp/vc/ediff-ptch.el b/lisp/vc/ediff-ptch.el
index 3effd9b..9f0e1dc 100644
--- a/lisp/vc/ediff-ptch.el
+++ b/lisp/vc/ediff-ptch.el
@@ -431,15 +431,15 @@ Please advise:
                 (f2-exists (setcar session-file-object file2))
                 (f1-exists (setcar session-file-object file1))
                 (t
-                  ;; TODO: Often for multipaches the file doesn't exist 
because the
-                  ;; directory part is wrong; for instance, if the patch need 
to
-                  ;; be applied into
+                  ;; TODO: Often for multi-patches the file doesn't exist
+                  ;; because the directory part is wrong; for instance, if the
+                  ;; patch needs to be applied into
                   ;; (expand-file-name "lisp/vc/ediff-ptch.el" 
source-directory)
                   ;; and default-directory is
                   ;; (expand-file-name "lisp" source-directory)
                   ;; then Ediff assumes the wrong file:
                   ;; (expand-file-name "lisp/ediff-ptch.el" source-directory).
-                  ;; We might identify these common failoures and suggest
+                  ;; We might identify these common failures and suggest
                   ;; in the prompt the possible corrected file. --Tino
                  (with-output-to-temp-buffer ediff-msg-buffer
                    (ediff-with-current-buffer standard-output
diff --git a/src/ChangeLog.13 b/src/ChangeLog.13
index 9e99895..e8ab5e0 100644
--- a/src/ChangeLog.13
+++ b/src/ChangeLog.13
@@ -17073,7 +17073,7 @@
 2013-05-04  Stefan Monnier  <address@hidden>
 
        * minibuf.c (Fread_minibuffer, Feval_minibuffer): Move to Elisp.
-       (syms_of_minibuf): Adjust accodingly.
+       (syms_of_minibuf): Adjust accordingly.
        * lread.c (Fread):
        * callint.c (Fcall_interactively): Adjust calls accordingly.
 
diff --git a/src/ChangeLog.3 b/src/ChangeLog.3
index a62aee7..256e4b7 100644
--- a/src/ChangeLog.3
+++ b/src/ChangeLog.3
@@ -11648,7 +11648,7 @@
 
        * fileio.c (Fcopy_file): Always close descriptors.
 
-       * s-sunos4.h: read, write, open and close are interruptable.
+       * s-sunos4.h: read, write, open and close are interruptible.
 
 1991-01-09  Jim Blandy  (address@hidden)
 
diff --git a/src/process.c b/src/process.c
index 9139a36..c5a46f9 100644
--- a/src/process.c
+++ b/src/process.c
@@ -4557,23 +4557,22 @@ from PROCESS only, suspending reading output from other 
processes.
 If JUST-THIS-ONE is an integer, don't run any timers either.
 Return non-nil if we received any output from PROCESS (or, if PROCESS
 is nil, from any process) before the timeout expired.  */)
-  (register Lisp_Object process, Lisp_Object seconds, Lisp_Object millisec, 
Lisp_Object just_this_one)
+  (Lisp_Object process, Lisp_Object seconds, Lisp_Object millisec,
+   Lisp_Object just_this_one)
 {
   intmax_t secs;
   int nsecs;
 
   if (! NILP (process))
     {
-      struct Lisp_Process *procp;
-
       CHECK_PROCESS (process);
-      procp = XPROCESS (process);
+      struct Lisp_Process *proc = XPROCESS (process);
 
       /* Can't wait for a process that is dedicated to a different
         thread.  */
-      if (!EQ (procp->thread, Qnil) && !EQ (procp->thread, Fcurrent_thread ()))
+      if (!EQ (proc->thread, Qnil) && !EQ (proc->thread, Fcurrent_thread ()))
        error ("Attempt to accept output from process %s locked to thread %s",
-              SDATA (procp->name), SDATA (XTHREAD (procp->thread)->name));
+              SDATA (proc->name), SDATA (XTHREAD (proc->thread)->name));
     }
   else
     just_this_one = Qnil;
diff --git a/src/systhread.c b/src/systhread.c
index 369d8f8..a2c556f 100644
--- a/src/systhread.c
+++ b/src/systhread.c
@@ -219,7 +219,7 @@ void
 sys_mutex_lock (sys_mutex_t *mutex)
 {
   /* FIXME: What happens if the owning thread exits without releasing
-     the mutex?  Accoding to MSDN, the result is undefined behavior.  */
+     the mutex?  According to MSDN, the result is undefined behavior.  */
   EnterCriticalSection ((LPCRITICAL_SECTION)mutex);
 }
 
diff --git a/src/thread.h b/src/thread.h
index 0090652..33f8ea7 100644
--- a/src/thread.h
+++ b/src/thread.h
@@ -48,7 +48,7 @@ struct thread_state
   /* The thread's function.  */
   Lisp_Object function;
 
-  /* If non-nil, this thread has been signalled.  */
+  /* If non-nil, this thread has been signaled.  */
   Lisp_Object error_symbol;
   Lisp_Object error_data;
 
@@ -60,7 +60,7 @@ struct thread_state
   /* A list of currently active byte-code execution value stacks.
      Fbyte_code adds an entry to the head of this list before it starts
      processing byte-code, and it removed the entry again when it is
-     done.  Signalling an error truncates the list.  */
+     done.  Signaling an error truncates the list.  */
   struct byte_stack *m_byte_stack_list;
 #define byte_stack_list (current_thread->m_byte_stack_list)
 
diff --git a/test/lisp/net/tramp-tests.el b/test/lisp/net/tramp-tests.el
index 2884187..3d92dff 100644
--- a/test/lisp/net/tramp-tests.el
+++ b/test/lisp/net/tramp-tests.el
@@ -2138,7 +2138,7 @@ This does not support special file names."
 
 (defun tramp--test-windows-nt-and-batch ()
   "Check, whether the locale host runs MS Windows in batch mode.
-This does not support scpecial characters."
+This does not support special characters."
   (and (eq system-type 'windows-nt) noninteractive))
 
 (defun tramp--test-windows-nt-and-pscp-psftp-p ()
diff --git a/test/lisp/vc/vc-tests.el b/test/lisp/vc/vc-tests.el
index 8dc72cd..b54a45d 100644
--- a/test/lisp/vc/vc-tests.el
+++ b/test/lisp/vc/vc-tests.el
@@ -206,7 +206,7 @@ For backends which dont support it, it is emulated."
 ;; FIXME: Why isn't there `vc-unregister'?
 (defun vc-test--unregister-function (backend file)
   "Run the `vc-unregister' backend function.
-For backends which don't support it, `vc-not-supported' is signalled."
+For backends which don't support it, `vc-not-supported' is signaled."
   ;; CVS, SVN, SCCS, SRC and Mtn are not supported, and will signal
   ;; `vc-not-supported'.
   (prog1
diff --git a/test/src/thread-tests.el b/test/src/thread-tests.el
index 26c0b72..73da72e 100644
--- a/test/src/thread-tests.el
+++ b/test/src/thread-tests.el
@@ -153,7 +153,7 @@
   (mutex-lock threads-mutex))
 
 (ert-deftest threads-mutex-signal ()
-  "test signalling a blocked thread"
+  "test signaling a blocked thread"
   (should
    (progn
      (setq threads-mutex (make-mutex))



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/src/thread.c b/src/thread.c
index 6966df3..9613d14 100644
--- a/src/thread.c
+++ b/src/thread.c
@@ -257,7 +257,7 @@ If the current thread already owns MUTEX, increment the 
count and
 return.
 Otherwise, if no thread owns MUTEX, make the current thread own it.
 Otherwise, block until MUTEX is available, or until the current thread
-is signalled using `thread-signal'.
+is signaled using `thread-signal'.
 Note that calls to `mutex-lock' and `mutex-unlock' must be paired.  */)
   (Lisp_Object mutex)
 {
@@ -363,8 +363,7 @@ condition_wait_callback (void *arg)
   XSETCONDVAR (cond, cvar);
   self->event_object = cond;
   saved_count = lisp_mutex_unlock_for_wait (&mutex->mutex);
-  /* If we were signalled while unlocking, we skip the wait, but we
-     still must reacquire our lock.  */
+  /* If signaled while unlocking, skip the wait but reacquire the lock.  */
   if (NILP (self->error_symbol))
     {
       self->wait_condvar = &cvar->cond;
@@ -384,7 +383,7 @@ The mutex associated with COND must be held when this is 
called.
 It is an error if it is not held.
 
 This releases the mutex and waits for COND to be notified or for
-this thread to be signalled with `thread-signal'.  When
+this thread to be signaled with `thread-signal'.  When
 `condition-wait' returns, COND's mutex will again be locked by
 this thread.  */)
   (Lisp_Object cond)
@@ -404,7 +403,7 @@ this thread.  */)
   return Qnil;
 }
 
-/* Used to communicate argumnets to condition_notify_callback.  */
+/* Used to communicate arguments to condition_notify_callback.  */
 struct notify_args
 {
   struct Lisp_CondVar *cvar;
@@ -814,7 +813,7 @@ or `thread-join' in the target thread.  */)
   if (tstate == current_thread)
     Fsignal (error_symbol, data);
 
   /* What to do if thread is already signalled?  */
   /* What if error_symbol is Qnil?  */
   tstate->error_symbol = error_symbol;
   tstate->error_data = data;
@@ -814,7 +813,7 @@ or `thread-join' in the target thread.  */)
     Fsignal (error_symbol, data);
 
-  /* What to do if thread is already signalled?  */
+  /* What to do if thread is already signaled?  */
   /* What if error_symbol is Qnil?  */
   tstate->error_symbol = error_symbol;